<?php

/**
 * @file
 * Contains Drupal\issue_2381277\Form\TestEmbeddedViewInForm.
 */

namespace Drupal\issue_2381277\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\views\ViewExecutableFactory;

/**
 * Class TestEmbeddedViewInForm.
 *
 * @package Drupal\issue_2381277\Form
 */
class TestEmbeddedViewInForm extends ConfigFormBase {

  /**
   * Drupal\views\ViewExecutableFactory definition.
   *
   * @var Drupal\views\ViewExecutableFactory
   */
  protected $views_executable;
  public function __construct(
    ConfigFactoryInterface $config_factory,
    ViewExecutableFactory $views_executable
  ) {
    parent::__construct($config_factory);
    $this->views_executable = $views_executable;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('views.executable')
    );
  }


  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'issue_2381277.testembeddedviewin_config'
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'test_embedded_view_in_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('issue_2381277.testembeddedviewin_config');
    
    $form['show_articles'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Show Articles')
    );
    $form['articles'] = array(
      '#type' => 'view',
      '#title' => $this->t('Test Text'),
      '#description' => $this->t(''),
      '#name' => 'articles',
      '#display_id' => 'block_1',
      '#states' => array(
        'invisible' => array(
         ':input[name=show_articles]' => array('checked' => FALSE),
        ),
      ),
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('issue_2381277.testembeddedviewin_config')
      ->set('test_view', $form_state->getValue('test_view'))
      ->set('test_text', $form_state->getValue('test_text'))
      ->save();
  }

}
